

set -ex



test -f $PREFIX/lib/libonedal.a
test -f $PREFIX/lib/libonedal_core.a
test -f $PREFIX/lib/libonedal_dpc.a
test -f $PREFIX/lib/libonedal_thread.a
test -f $PREFIX/lib/libdaal_thread.a
test -f $PREFIX/lib/libdaal_core.a
exit 0
